@@ -11,7 +11,6 @@ _template_name = 'graphql-docs.html'
 _jinja_env = Environment(
     loader=PackageLoader('graphdoc', 'templates'),
     autoescape=select_autoescape(['html', 'xml']),
-    enable_async=True
 )
 _jinja_env.filters['slugify'] = filters.slugify
 _jinja_env.filters['markdown'] = filters.markdown
@@ -32,20 +31,3 @@ def to_doc(
         configs=configs
     )
     return html
-
-
-async def to_doc_async(
-        schema: Union[str, graphql.GraphQLSchema],
-        **configs
-) -> str:
-    """
-    Returns an html with the documentation from the schema using
-    jinja's asyncio implementation
-    """
-    configs = {**default_config, **configs}
-    reference = utilities.build_types_reference(schema)
-    html = await _jinja_env.get_template(_template_name).render_async(
-        reference=reference,
-        configs=configs
-    )
-    return html
