@@ -84,6 +84,9 @@ def build_types_reference(
             reference.unions.append(obj)
 
         elif isinstance(obj, graphql.GraphQLEnumType):
+            if isinstance(obj.values, list):
+                # graphql-core>=2.1.0,<3
+                obj.values = {v.name: v for v in obj.values}
             reference.enums.append(obj)
 
         elif isinstance(obj, graphql.GraphQLInputObjectType):
